# Ecogesture

## Description

An ecogesture is a gesture that encourages user to take action for reduce their own consumption.

It includes different information such as icon, name, long and short description, its efficiency on the consumption and which fluid is affected.

Also, an ecogesture can be used for an action challenge.

### Model

```ts
Ecogesture {
  id: string
  shortName: string
  longName: string
  longDescription: string
  usage: Usage
  fluidTypes: FluidType[]
  impactLevel: number
  efficiency: number
  difficulty: number
  room: Room[]
  season: Season
  equipment: boolean
  equipmentType: EquipmentType[]
  equipmentInstallation: boolean
  investment: string | null
  action: boolean
  actionName: string | null
  actionDuration: number
  objective: boolean
  doing: boolean
  viewedInSelection: boolean
}
```

## Ecogestures screen

This screen is divided in 3 tabs :

- *ALL*: display the full list of ecogestures. User can filter ecogesture by usage.
- *DOING*: display the list of doing ecogestures. User can filter ecogesture by usage.
- *OBJECTIVES*: display the list of objectives ecogestures. User can filter ecogesture by usage.

### RULES

- By default the *ALL* tab is selected.
- If user click on an ecogesture, he will see more information about it and will be able to choose manually if it is *doing* AND/OR *objective*
- The back arrow button on a single ecogesture returns to the tab he came through.

### Ecogesture Status

An ecogesture can have a status according the user's choice, it can be *doing* and/or *objective* which allows the user to consult them in the related tabs in the ecogesture page. On it is selected by the user in the tinder-like tunnel, the *viewedInSelection* key is set to true, so the user won't see it again in its selection.

## Profile Ecogesture

The first time the user consults the ecogesture page, he will be prompted to start selecting his custom ecogestures.

- If he refuses, I will still be able to access this functionality by clicking on the "Select" button on the tabs 'Doing' and 'Objectives' while they are still empty.
- If he starts select ecogestures on his own by the tab 'All' and fill both 'objective' and 'doing' sections, he won't be able to access the form and selection as described in the next parts.

### Model

```ts
ProfileEcogesture {
  heating: IndividualOrCollective
  warmingFluid: WarmingType | null
  hotWater: IndividualOrCollective
  equipments: EquipmentType[]
}
```

### Ecogesture Form

The form is compose in 2 parts :

- The first is made of question concerning his heating fluid and type (individual or collective), and his hotWater type.
- The second part asks the user to pick the equipment he has.

*If the user has completed his profileType, he won't see the first part as it is automatically completed with the information he filled in his profileType:*

- The first part filters his custom list by Usages ECS and HEATING
- The second part filters his custom list by Equipments

## Ecogesture Selection

Once user has completed his profile ecogesture through the form, he has the possibility to enter the ecogesture selection (tinder-like)

- A list of custom ecogesture is made according to his profile
- User will cross this list 10 by 10, and has to choose if it is 'doing' 'objective' or 'not interested

### Important Rules

- If uses refuses to do the selection for now, he will be reminded to do it in the 'doing' and 'objective' tabs, and a continue button will show
- User can go back and correct his answer at any time
- User can stop the process at any time, hist answer will be saved ad the next time he will open the selection, a new stack of 10 ecogesture is made (for example, user stops at 4/10, the next time he opens the selection it will be 4/14)
- If user chooses to select manually an ecogesture outside of the selection tunnel (through the 'all' tab), this ecogesture will be removed from the list it was existing in it.
- If user chooses to remove manually an ecogesture outside of the selection tunnel (through the 'doing' and 'objective' tab), these ecogestures won't be purposes again in the selection tunnel.
- User can't use the back arrow on the first ecogesture of selection list

Once the whole process is done, the user has no possibility to do it again through the tinder-like selection, but he can still edit his ecogestures manually from the various tabs.

### Case ecogesture usage is heating

We will display the ecogesture if:

- the ecogesture has electricity fluid and profile type has an individual heating which use electricity fluid.

OR

- the ecogesture has gas fluid and profile type has an individual heating which use gas fluid.

### Case ecogesture usage is ECS

> `ECS = Eau chaude sanitaire`

We will display the ecogesture if:

- the ecogesture has electricity fluid and profile type has an individual hot water which use electricity fluid.

OR

- the ecogesture has gas fluid and profile type has an individual hot water which use gas fluid.

### Case ecogesture usage is Cooking

We will display the ecogesture if:

- the ecogesture has electricity fluid and profile type has an electricity fluid for cooking.

OR

- the ecogesture has gas fluid and profile type has an gas fluid for cooking.

### Case ecogesture usage is cold water

We will display the ecogesture if the profile type has individual cold water.

### Case ecogesture usage is specific electricity

We will display the ecogesture.

### Case ecogesture usage is air conditioning

We will NOT display the ecogesture.
