# Usage events tracking

This section explains how the application is tracking usage events. Here are the main step:

- All events are stored during the use of the application in the doctype **com.grandlyon.ecolyo.usageevents**
- A service is responsible of the aggregation of these events to create ANONYMIZED indicators. These indicators are then sent to a remote docType.

## Usage events collection

During the use of the application we stored some events link to an user action. Here are the list of collected usage events:

| Category    | Type                           | Target         | Result               | Context               | Description                               |
| ----------- | ------------------------------ | -------------- | -------------------- | --------------------- | ----------------------------------------- |
| Connection  | ConnectionEvent                |                |                      | "desktop" or "mobile" | User connects to the application.         |
| Navigation  | NavigationEvent                | Page_name      |                      |                       | User navigates to a targeted page.        |
| Konnector   | KonnectorConnectEvent          | Konnector_slug | "success" or "error" |                       | User connects a konnector.                |
| Konnector   | KonnectorRefreshEvent          | Konnector_slug | "success" or "error" |                       | User refreshes a konnector.               |
| Challenge   | ChallengeLaunchEvent           | Challenge_id   |                      |                       | User launches a challenge.                |
| Challenge   | ChallengeEndEvent              | Challenge_id   |                      |                       | User ends a challenge.                    |
| Duel        | DuelLaunchEvent                | Duel_id        |                      | Challenge_id          | User launches a duel.                     |
| Duel        | DuelEndEvent                   | Duel_id        |                      | Challenge_id          | User ends a duel.                         |
| Quiz        | QuizEndEvent                   | Quiz_id        | starsNumber          | Challenge_id          | User ends a quiz.                         |
| Exploration | ExplorationEndEvent            | Exploration_id |                      | Challenge_id          | User ends an exploration.                 |
| Action      | ActionChangeEvent              | Action_id      |                      | Challenge_id          | User change action's ecogesture.          |
| Action      | ActionEndEvent                 | Action_id      |                      | Challenge_id          | User ends a action.                       |
| Profile     | ProfileSetEvent                |                |                      |                       | User fills in its profile.                |
| Consumption | ConsumptionCompareEvent        |                |                      | Fluid / TimeStep      | User compares its consumption.            |
| Consumption | ConsumptionChangeTimeStepEvent | TimeStep       |                      | Fluid                 | User changes timeStep of its consumption. |
| Consumption | ConsumptionInteracteEvent      |                |                      | Fluid / TimeStep      | User selects a consumption on the chart.  |

All events are stored with the _aggregated_ flag to false to allow the identification of new events.

## Usage events aggregator service

## Functionalities

The service will retrieve all new events by filter on the _aggregated_ flag to **false** and the event date before than today.
For each aggregator type we will defined the right calculation to apply to create the appropriate indicator:

- calculation of the session time indicator based on ConnectionEvent
- calculation of the konnectors connected per day based on the fluidStatus
- calculates if a user launched a duel just after earned 15 stars
- calculation of the period between 2 different challenges based on the ChallengeLaunchEvent
- calculation of the period between the first connection and the first challenge based on ChallengeLaunchEvent and ConnectionEvent
- calculation of an indicator based on a single event
- calculation of an aggregated indicator to sum an event type per days.

Once the indicators is calculated we will:

1. post the indicator to the remote doctype
2. push the event used to calculate the indicator to a array, which will be used to identify all events taken into account during the process.

At the end of the service, the service will change the _aggregated_ flag to **true** for all events present in the array.

More technical information are available [here](/ecolyo/technical/services/aggregator_usage_events/)

## Remote doctype

All indicator are post to a remote doctype, which will allow the application to read a defined external API. This doctype is created by Cozy itself.
Here are the actual structure of this remote doctype:

```ts
{
  source: string
  name: string
  startDate: string
  endDate: string
  value?: number
  groups: { [key: string]: string }
}
```

with:

- source: contains "ecolyo" value.
- name: contains the indicator type
- startDate and endDate: used to defined a period or if not relevant, it contains both the date of the events.
- value: contains aggregated value (example: number of page viewed on a day).
- groups: contains all other attribute useful for the indicator (example: context, target, result)
