# Doctypes

Doctypes represent different types of data. Their primary use is for permissions: an app or konnector will request permissions for one or several doctypes and will not be able to access other doctypes. See [Doctypes documentation](https://docs.cozy.io/en/cozy-doctypes/docs/) for more information.

The following is a full description of the doctypes we use and their fields. Cozy doctypes won't be fully described. Instead, for every used one, we'll include a link to its official documentation.

## Used Cozy doctypes

- [`io.cozy.accounts`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.accounts): Konnector accounts
- [`io.cozy.apps`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.apps/): Installed apps
- [`io.cozy.contacts`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.contacts): Contacts
- [`io.cozy.contacts.groups`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.contacts.groups): Contacts groups
- [`io.cozy.files`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.files): Files
- [`io.cozy.permissions`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.permissions): Permissions of the instance
- [`io.cozy.konnectors`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.konnectors/): Konnectors
- [`io.cozy.triggers`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.triggers): Job triggers

## Used Cozy remote doctypes

This kind of doctype are set from the team. We have push two remote doctypes (each duplicate for rec and prod environment)

> Prod

- [`org.mps.store`]: Required to store information on back-end TS
- [`org.mps.share`]: Required to search on back-end TS

> Recette

- [`org.mps.store.rec`]: Required to store information on rec back-end TS
- [`org.mps.share.rec`]: Required to search on rec back-end TS

If you need to target rec remote doctype, you need to change the request : client.getStackClient().fetchJSON('POST','...')
and change them into the manifest also.

## Custom doctypes

- `com.grandlyon.mps.profile`
    - `tutorial`: {`object`} contains `contacts`, `documents`, `actions`, and `notes`. They represent the state of tutorials. For example, `contacts: true` means the contacts tutorial hasn't been seen yet and will be visible to the user the next time he visits the contacts component.
    - `notification`:  {`boolean`} If equals true, the user has a notification
    - `fullname`: {`string`} User's full name
    - `introduction`: {`boolean`} If equals `true`, it means the user has already used the app and seen the introduction.
    - `lastConnectionDate` : {`string`} When was the user last connected (ISO string).
    - `hasPhone`: {`boolean`} Equals true if the current user has already a phone number
    - `userID`: {`string`} Current user id
    - `publicProfile`: {`object`} contains `fullname`, `endDate` (ISO string), and `isActive`

- `com.grandlyon.mps.appointments`
    - `id`: {`string`} the appointment id
    - `appointmentDate`: {`string`} the appointment date (ISO string)
    - `note`: {`Note`} A unique note for each appointment
    - `objectives`: {`Array<Objective>`} The list of appointment's objectives

- `com.grandlyon.mps.objectives`
    - `id`: {`string`} the objective id
    - `title`: {`string`} the objective title
    - `type`: {`string`} The id of the Objective type
    - `subtype`: {`string`} The id of the Objective subType
    - `tasks`: {`Array<Task>`} Array of Tasks ids
    - `archived`: {`boolean`}  If equals true, it mean the objective has been completed

- `com.grandlyon.mps.tasks`
    - `id`: {`string`} The task id
    - `name`: {`string`} The task name
    - `description`: {`string`} The task description
    - `state`: {`TaskState`} It could be one of the following: `'USER_TO_VALID', 'USER_VALID', 'PUBLIC_VALID', 'PUBLIC_INVALID'`
    - `qualifications`: {`Array<string>`}
    - `items`: {`Array<TaskItem>`}

- `com.grandlyon.mps.task.items`
    - `id`: {`string`} Item id
    - `file`: {`DocumentEntity`} The items' file
    - `state`: {`TaskItemState`} It could be one of the following: `'USER_ITEM_PENDING', 'PUBLIC_ITEM_VALID', 'PUBLIC_ITEM_INVALID'`

- `com.grandlyon.mps.notes`
    - `id`: {`string`} Note's id
    - `content`: {`string`} The content of the note.
    - `createdAt`: {`string`} Date of creation (ISO string)
